@@ -6,7 +6,7 @@ Est.Mean.Hajek <- function(VecY.s, VecPk.s)
   if(any(VecPk.s<=0|VecPk.s>1)       ){stop("There are invalid values in VecPk.s.")            }
   if(any(is.na(VecY.s))              ){stop("There are missing values in VecY.s.")             }
   n                                   <- length(VecY.s)
-  if(n != as.integer(length(VecPk.s))){stop("The lengths of VecY.s and VecPk.s are different.")}
+  if(n != length(VecPk.s)            ){stop("The lengths of VecY.s and VecPk.s are different.")}
   .C("Est_Mean_Hajek", 
       as.double(VecY.s), 
       as.double(VecPk.s), 
